@@ -1,8 +1,10 @@
-
-from pywizard.resources.package import PackageProvider, register_package_provider, package
 import apt
+from pywizard.compat.os_debian.facts import os_ubuntu
+
 from pywizard.resources.shell import shell
-from pywizard.worker import worker
+
+from pywizard.core.env import worker
+from pywizard.resources.package import PackageProvider, register_package_provider
 
 
 class AptPackageProvider(PackageProvider):
@@ -12,7 +14,7 @@ class AptPackageProvider(PackageProvider):
         return 'apt'
 
     def can_install_system_packages(self):
-        return True
+        return os_ubuntu()
 
     def install_packages(self, packages, version=None):
         cache = apt.Cache()
@@ -38,10 +40,9 @@ class AptPackageProvider(PackageProvider):
 
         return set(installed)
 
+#
+# def install_libs():
+#     shell('apt-get install libapt-pkg-dev')
+#     shell('pip install python-apt')
+# worker.env.requirements.append(install_libs)
 
-def install_libs():
-    shell('apt-get install libapt-pkg-dev')
-    shell('pip install python-apt')
-worker.env.requirements.append(install_libs)
-
-register_package_provider(AptPackageProvider)
\ No newline at end of file
