@@ -1,6 +1,6 @@
-import re
-from pywizard.resources.package import PackageProvider, register_package_provider, package
-from pywizard.utils.process import run
+from pywizard.compat.os_centos.facts import os_centos
+from pywizard.resources.package import PackageProvider, register_package_provider
+from pywizard.process import run
 import yum
 
 
@@ -15,7 +15,7 @@ class YumPackageProvider(PackageProvider):
         return 'yum'
 
     def can_install_system_packages(self):
-        return True
+        return os_centos()
 
     def install_packages(self, packages, version=None):
         yb = yum.YumBase()
@@ -44,4 +44,4 @@ class YumPackageProvider(PackageProvider):
 
         return set(installed)
 
-register_package_provider(YumPackageProvider)
+register_package_provider(YumPackageProvider)
\ No newline at end of file
