@@ -1,5 +1,4 @@
-from _pytest.python import raises
-from pywizard.resource import CanNotResolveConflictError, Item, Resource
+from pywizard.resource import CanNotResolveConflictError, Resource
 
 
 def test_exception():
